Adafruit IO Python
==================

.. image:: https://readthedocs.org/projects/adafruit-io-python-client/badge/?version=latest
    :target: https://adafruit-io-python-client.readthedocs.io/en/latest/
    :alt: Documentation Status

.. image:: https://img.shields.io/discord/327254708534116352.svg
   :target: https://discord.gg/nBQh6qu
   :alt: Chat

.. image:: https://travis-ci.org/adafruit/io-client-python.svg?branch=master
    :target: https://travis-ci.org/adafruit/io-client-python
    :alt: Build Status

.. image:: https://cdn-learn.adafruit.com/assets/assets/000/057/153/original/adafruit_io_iopython.png?1530802073

A Python client and examples for use with `io.adafruit.com <https://io.adafruit.com>`_. 

Compatible with Python Versions 3.4+

Installation
================

Easy Installation
~~~~~~~~~~~~~~~~~
If you have `PIP <https://pip.pypa.io/en/stable/installing/>`_ installed (typically with apt-get install python-pip on a Debian/Ubuntu-based system) then run:

.. code-block:: shell

   pip3 install adafruit-io

This will automatically install the Adafruit IO Python client code for your Python scripts to use. You might want to examine the examples folder in this GitHub repository to see examples of usage.


Manual Installation
~~~~~~~~~~~~~~~~~~~

Clone or download the contents of this repository. Then navigate to the folder in a terminal and run the following command:


.. code-block:: shell

   python setup.py install




Usage 
=====

Documentation for this project is `available on the ReadTheDocs <https://adafruit-io-python-client.readthedocs.io/en/latest/>`_.


Contributing
============

Contributions are welcome! Please read our `Code of Conduct
<https://github.com/adafruit/CircuitPython_io-client-python/blob/master/CODE_OF_CONDUCT.md>`_
before contributing to help this project stay welcoming.
